
#ifndef __LASTFM_H__
#define __LASTFM_H__

void
lastfm_login(char **arglist);

int
lastfm_scrobble(int id);

#endif /* !__LASTFM_H__ */
